import throttle from 'just-throttle';
import { useEffect, useMemo } from 'react';
/**
 * Custom Hook that calls a callback function each time a scroll event occurs
 * @param effect callback function
 * @param options.waitingMs Waiting time after function execution
 * @see https://developer.mozilla.org/en-US/docs/Web/API/EventTarget/addEventListener#parameters
 */
export var useWindowScrollEffect = function (effect, options) {
    if (options === void 0) { options = {}; }
    var scrollEffect = useMemo(function () {
        return throttle(function () {
            effect(window.scrollY);
        }, options.waitingMs || 0);
    }, [effect, options.waitingMs]);
    useEffect(function () {
        window.addEventListener('scroll', scrollEffect, options);
        return function () {
            window.removeEventListener('scroll', scrollEffect);
        };
    }, [options, scrollEffect]);
};
