declare type Options = {
    disableValueChangesOffscreen: boolean;
    scrollStartPosition: 'window-top' | 'window-center' | 'window-bottom';
    scrollEndPosition: 'window-top' | 'window-center' | 'window-bottom';
    waitingMs?: number;
};
/**
 * Hooks to get how much the window has scrolled from the target element.
 * @param targetElmRef target element
 * @param opts
 * @returns result
 * @returns result.position Get the position of the "top/bottom" of the window in px within the target element.
 * @returns result.position.top
 * @returns result.position.bottom
 * @returns result.fraction Get the position of the "top/bottom" of the window as a percentage of the target element's scrollable area with the height of the target element as 100%.
 * @returns result.fraction.top
 * @returns result.fraction.bottom
 * @returns result.isFraction window is within the scrollable area of the element * @returns result.isFraction window is within the scrollable area of the element?
 */
export declare const useWindowScrollInElement: (targetElmRef: React.RefObject<HTMLElement>, opts?: Partial<Options>) => {
    position: {
        top: number;
        bottom: number;
    };
    fraction: {
        top: number;
        bottom: number;
    };
    isInside: boolean;
};
export {};
